/* telnet.h -- basic telnet protocol handling for ttywatch
 *
 * Copyright  2001 Michael K. Johnson <johnsonm@redhat.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */


#ifndef __TELNET_H__
#define __TELNET_H__

#include "ttywatch.h"

void
telnet_negotiate_server(int socket);
void
telnet_negotiate_client(int socket);
int
telnet_process_input(net_conn *nc, char *data, int len);
int
telnet_data_has_break(net_conn *nc, char *data, int len);
void
telnet_send_output(net_conn *nc, char *data, int len);

#endif /* __TELNET_H__ */
